Rename `upstream` directory to simply `prebuilt`

The name `upstream` doesn't have any meaning anymore now that there is
no more fastcomp.  It was removed from the SDK names in #1166 and this
is the last usage of that name/term.
diff --git a/.flake8 b/.flake8
index b67d9c2..a1458f4 100644
--- a/.flake8
+++ b/.flake8
@@ -8,8 +8,7 @@
 exclude =
   ./llvm
   ./gnu
-  ./upstream
-  ./fastcomp
+  ./prebuilt
   ./fastcomp-clang
   ./releases
   ./clang
diff --git a/.gitignore b/.gitignore
index 0d794d2..ab8006a 100644
--- a/.gitignore
+++ b/.gitignore
@@ -15,9 +15,7 @@
 # File that get download/extracted by emsdk itself
 /ccache
 /gnu
-/upstream
-/fastcomp
-/fastcomp-clang/
+/prebuilt
 /llvm
 /ninja
 /releases
diff --git a/README.md b/README.md
index 33c7c60..6bb29d6 100644
--- a/README.md
+++ b/README.md
@@ -136,11 +136,11 @@
 When you run `emsdk list`, it will group the Tools and SDKs under these two
 categories.
 
-To obtain and build latest upstream wasm SDK from source, run
+To obtain and build latest wasm SDK from source, run
 
 ```
-emsdk install sdk-upstream-main-64bit
-emsdk activate sdk-upstream-main-64bit
+emsdk install sdk-main-64bit
+emsdk activate sdk-main-64bit
 ```
 
 You can use this target for example to bootstrap developing patches to LLVM,
@@ -156,7 +156,7 @@
 ### When working on git branches compiled from source, how do I update to a newer compiler version?
 
 Unlike tags and precompiled versions, a few of the SDK packages are based on
-"moving" git branches and compiled from source (e.g. sdk-upstream-main,
+"moving" git branches and compiled from source (e.g. sdk-main,
 sdk-main, emscripten-main, binaryen-main). Because of that, the
 compiled versions will eventually go out of date as new commits are introduced
 to the development branches. To update an old compiled installation of one of
@@ -198,11 +198,11 @@
 obtain new features and latest fixes immediately as they are pushed to the
 github repository, without having to wait for release to be tagged. You do not
 need a github account or a fork of Emscripten to do this. To switch to using the
-latest upstream git development branch `main`, run the following:
+latest git development branch `main`, run the following:
 
     emsdk install git-1.9.4 # Install git. Skip if the system already has it.
-    emsdk install sdk-upstream-main-64bit # Clone+pull the latest emscripten-core/emscripten/main.
-    emsdk activate sdk-upstream-main-64bit # Set the main SDK as the currently active one.
+    emsdk install sdk-main-64bit # Clone+pull the latest emscripten-core/emscripten/main.
+    emsdk activate sdk-main-64bit # Set the main SDK as the currently active one.
 
 ### How do I use my own Emscripten github fork with the SDK?
 
diff --git a/docker/Dockerfile b/docker/Dockerfile
index 508d7b3..62817ca 100644
--- a/docker/Dockerfile
+++ b/docker/Dockerfile
@@ -32,11 +32,11 @@
 RUN cd ${EMSDK} \
     && echo "## Generate standard configuration" \
     && ./emsdk activate ${EMSCRIPTEN_VERSION} \
-    && chmod 777 ${EMSDK}/upstream/emscripten \
-    && chmod -R 777 ${EMSDK}/upstream/emscripten/cache \
+    && chmod 777 ${EMSDK}/prebuilt/emscripten \
+    && chmod -R 777 ${EMSDK}/prebuilt/emscripten/cache \
     && echo "int main() { return 0; }" > hello.c \
-    && ${EMSDK}/upstream/emscripten/emcc -c hello.c \
-    && cat ${EMSDK}/upstream/emscripten/cache/sanity.txt \
+    && ${EMSDK}/prebuilt/emscripten/emcc -c hello.c \
+    && cat ${EMSDK}/prebuilt/emscripten/cache/sanity.txt \
     && echo "## Done"
 
 # Cleanup Emscripten installation and strip some symbols
@@ -45,11 +45,11 @@
     # Remove debugging symbols from embedded node (extra 7MB)
     && strip -s `which node` \
     # Tests consume ~80MB disc space
-    && rm -fr ${EMSDK}/upstream/emscripten/tests \
+    && rm -fr ${EMSDK}/prebuilt/emscripten/tests \
     # Fastcomp is not supported
-    && rm -fr ${EMSDK}/upstream/fastcomp \
+    && rm -fr ${EMSDK}/prebuilt/fastcomp \
     # strip out symbols from clang (~extra 50MB disc space)
-    && find ${EMSDK}/upstream/bin -type f -exec strip -s {} + || true \
+    && find ${EMSDK}/prebuilt/bin -type f -exec strip -s {} + || true \
     && echo "## Done"
 
 # ------------------------------------------------------------------------------
@@ -65,7 +65,7 @@
 # (sub-stages) or with custom / no entrypoint
 ENV EMSDK=/emsdk \
     EMSDK_NODE=/emsdk/node/14.18.2_64bit/bin/node \
-    PATH="/emsdk:/emsdk/upstream/emscripten:/emsdk/upstream/bin:/emsdk/node/14.18.2_64bit/bin:${PATH}"
+    PATH="/emsdk:/emsdk/prebuilt/emscripten:/emsdk/prebuilt/bin:/emsdk/node/14.18.2_64bit/bin:${PATH}"
 
 # ------------------------------------------------------------------------------
 # Create a 'standard` 1000:1000 user
diff --git a/emsdk_manifest.json b/emsdk_manifest.json
index 927cdd9..d0510fd 100644
--- a/emsdk_manifest.json
+++ b/emsdk_manifest.json
@@ -38,7 +38,7 @@
     "macos_url": "https://storage.googleapis.com/webassembly/emscripten-releases-builds/mac/%releases-tag%/wasm-binaries.tbz2",
     "windows_url": "https://storage.googleapis.com/webassembly/emscripten-releases-builds/win/%releases-tag%/wasm-binaries.zip",
     "zipfile_prefix": "%releases-tag%-",
-    "install_path": "upstream",
+    "install_path": "prebuilt",
     "activated_path": "%installation_dir%/emscripten",
     "activated_cfg": "LLVM_ROOT='%installation_dir%/bin';BINARYEN_ROOT='%installation_dir%';EMSCRIPTEN_ROOT='%installation_dir%/emscripten'",
     "emscripten_releases_hash": "%releases-tag%"
@@ -51,7 +51,7 @@
     "macos_url": "https://storage.googleapis.com/webassembly/emscripten-releases-builds/mac/%releases-tag%/wasm-binaries-arm64.tbz2",
     "linux_url": "https://storage.googleapis.com/webassembly/emscripten-releases-builds/linux/%releases-tag%/wasm-binaries-arm64.tbz2",
     "zipfile_prefix": "%releases-tag%-",
-    "install_path": "upstream",
+    "install_path": "prebuilt",
     "activated_path": "%installation_dir%/emscripten",
     "activated_cfg": "LLVM_ROOT='%installation_dir%/bin';BINARYEN_ROOT='%installation_dir%';EMSCRIPTEN_ROOT='%installation_dir%/emscripten'",
     "emscripten_releases_hash": "%releases-tag%"
diff --git a/test/test_activation.ps1 b/test/test_activation.ps1
index 6d38ffc..851244a 100644
--- a/test/test_activation.ps1
+++ b/test/test_activation.ps1
@@ -58,9 +58,9 @@
         throw "$repo_root\\node is not added to path."
     }
 
-    $EMSDK_UPSTREAM_Path = $path_split | Where-Object { $_ -like "$repo_root\upstream\emscripten*" }
+    $EMSDK_UPSTREAM_Path = $path_split | Where-Object { $_ -like "$repo_root\prebuilt\emscripten*" }
     if (!$EMSDK_UPSTREAM_Path) {
-        throw "$repo_root\\upstream\emscripten is not added to path."
+        throw "$repo_root\\prebuilt\emscripten is not added to path."
     }
 
 
diff --git a/test/test_path_preservation.ps1 b/test/test_path_preservation.ps1
index 1547949..d25bddd 100644
--- a/test/test_path_preservation.ps1
+++ b/test/test_path_preservation.ps1
@@ -42,7 +42,7 @@
     $EMSDK_NODE_Path = $path_arr | Where-Object { $_ -like "$repo_root\node*" }
     $EMSDK_PYTHON_Path = $path_arr | Where-Object { $_ -like "$repo_root\python*" }
     $EMSDK_JAVA_Path = $path_arr | Where-Object { $_ -like "$repo_root\java*" }
-    $EMSDK_UPSTREAM_Path = $path_arr | Where-Object { $_ -like "$repo_root\upstream\emscripten*" }
+    $EMSDK_UPSTREAM_Path = $path_arr | Where-Object { $_ -like "$repo_root\prebuilt\emscripten*" }
 
     $number_of_items = $path_arr.count
     [System.Collections.ArrayList]$rest_of_path = @()
@@ -52,7 +52,7 @@
             ($item -like "$repo_root\node*") -or
             ($item -like "$repo_root\python*") -or
             ($item -like "$repo_root\java*") -or
-            ($item -like "$repo_root\upstream\emscripten*")
+            ($item -like "$repo_root\prebuilt\emscripten*")
         ) {
             echo "$item is on the PATH"
         }
diff --git a/emsdk.py b/emsdk.py
index 12bbb2c..f3d37b1 100644
--- a/emsdk.py
+++ b/emsdk.py
@@ -1919,9 +1919,9 @@
       return False
 
     if getattr(self, 'custom_install_script', None) == 'emscripten_npm_install':
-      # upstream tools have hardcoded paths that are not stored in emsdk_manifest.json registry
-      install_path = 'upstream'
-      emscripten_dir = os.path.join(EMSDK_PATH, install_path, 'emscripten')
+      # prebuilt sdk tools have hardcoded paths that are not stored in
+      # emsdk_manifest.json registry
+      emscripten_dir = os.path.join(EMSDK_PATH, 'prebuilt', 'emscripten')
       # Older versions of the sdk did not include the node_modules directory
       # and require `npm ci` to be run post-install
       if not os.path.exists(os.path.join(emscripten_dir, 'node_modules')):
@@ -2244,7 +2244,7 @@
 
 
 def get_installed_sdk_version():
-  version_file = sdk_path(os.path.join('upstream', '.emsdk_version'))
+  version_file = sdk_path(os.path.join('prebuilt', '.emsdk_version'))
   if not os.path.exists(version_file):
     return None
   with open(version_file) as f: